<!DOCTYPE TS><TS>
<context>
    <name>QObject</name>
    <message>
        <source>Null</source>
        <comment>Type name</comment>
        <translation>Null</translation>
    </message>
    <message>
        <source>Bool</source>
        <comment>Type name</comment>
        <translation>Bool</translation>
    </message>
    <message>
        <source>Int</source>
        <comment>Type name</comment>
        <translation>Int</translation>
    </message>
    <message>
        <source>Real</source>
        <comment>Type name</comment>
        <translation>Real</translation>
    </message>
    <message>
        <source>String</source>
        <comment>Type name</comment>
        <translation>Řetězec</translation>
    </message>
    <message>
        <source>Name</source>
        <comment>Type name</comment>
        <translation>Jméno</translation>
    </message>
    <message>
        <source>Ref</source>
        <comment>Type name</comment>
        <translation>Odkaz</translation>
    </message>
    <message>
        <source>Array</source>
        <comment>Type name</comment>
        <translation>Pole</translation>
    </message>
    <message>
        <source>Dict</source>
        <comment>Type name</comment>
        <translation>Slovník</translation>
    </message>
    <message>
        <source>Stream</source>
        <comment>Type name</comment>
        <translation>Stream</translation>
    </message>
    <message>
        <source>DebugCmd</source>
        <comment>Type name</comment>
        <translation>DebugCmd</translation>
    </message>
    <message>
        <source>DebugError</source>
        <comment>Type name</comment>
        <translation>DebugError</translation>
    </message>
    <message>
        <source>DebugEOF</source>
        <comment>Type name</comment>
        <translation>DebugEOF</translation>
    </message>
    <message>
        <source>DebugNone</source>
        <comment>Type name</comment>
        <translation>DebugNone</translation>
    </message>
    <message>
        <source>&lt;no name&gt;</source>
        <translation>&lt;bez jména&gt;</translation>
    </message>
    <message>
        <source>Fatal Error</source>
        <translation>Kritická chyba</translation>
    </message>
    <message>
        <source>Options: </source>
        <translation>Přepínače: </translation>
    </message>
    <message>
        <source>Print help and exit</source>
        <translation>Vypsat nápovědu a skončit</translation>
    </message>
    <message>
        <source>Print version and exit</source>
        <translation>Vypsat verzi a skončit</translation>
    </message>
    <message>
        <source>Stop processing options</source>
        <translation>Přestat zpracovávat přepínače</translation>
    </message>
    <message>
        <source>Invalid commandline option : </source>
        <translation>Nesprávný přepínač na příkazové řádce : </translation>
    </message>
    <message>
        <source>PDF files (*.pdf)</source>
        <translation>PDF soubory (*.pdf)</translation>
    </message>
    <message>
        <source>Open file ...</source>
        <translation>Otevřít soubor ...</translation>
    </message>
    <message>
        <source>Save file as ...</source>
        <translation>Uložit soubor jako ...</translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <source>&amp;Yes</source>
        <translation>&amp;Ano</translation>
    </message>
    <message>
        <source>&amp;No</source>
        <translation>&amp;Ne</translation>
    </message>
    <message>
        <source>&amp;Apply</source>
        <translation>&amp;Použít</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Storno</translation>
    </message>
    <message>
        <source>PDF</source>
        <translation>PDF</translation>
    </message>
    <message>
        <source>Dictionary</source>
        <translation>Slovník</translation>
    </message>
    <message>
        <source>List</source>
        <translation>Seznam</translation>
    </message>
    <message>
        <source>Page</source>
        <translation>Strana</translation>
    </message>
    <message>
        <source>&amp;Index</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Zavřít</translation>
    </message>
    <message>
        <source>Invalid %1 in config:
Name: %2
Data: %3
</source>
        <translation>Chybná položka typu %1 v konfiguraci:
Jméno: %2
Data: %3
</translation>
    </message>
    <message>
        <source>Expected: </source>
        <translation>Očekáváno: </translation>
    </message>
    <message>
        <source>Missing item in config</source>
        <translation>Chybějící položka v konfiguraci</translation>
    </message>
    <message>
        <source>menu definition</source>
        <translation>definice menu</translation>
    </message>
    <message>
        <source>menu item</source>
        <translation>položka menu</translation>
    </message>
    <message>
        <source>2 or more parameters in item definition</source>
        <translation>2 nebo více parametrů v definici položky</translation>
    </message>
    <message>
        <source>toolbar item</source>
        <translation>položka toolbaru</translation>
    </message>
    <message>
        <source>4 parameters in item definition</source>
        <translation>4 parametry v definici položky</translation>
    </message>
    <message>
        <source>toolbar definition</source>
        <translation>definice toolbaru</translation>
    </message>
    <message>
        <source>Cycle in menu detected</source>
        <translation>Nalezen cyklus v menu</translation>
    </message>
    <message>
        <source>Catalog</source>
        <translation>Katalog</translation>
    </message>
    <message>
        <source>Menu items list</source>
        <translation>Seznam menu položek</translation>
    </message>
    <message>
        <source>&amp;Add object</source>
        <translation>Přid&amp;at objekt</translation>
    </message>
    <message>
        <source>Add and c&amp;lose</source>
        <translation>Přidat a zavřít</translation>
    </message>
    <message>
        <source>Stream</source>
        <translation>Stream</translation>
    </message>
    <message>
        <source>Parameter missing for option : </source>
        <translation>Chybí parametr pro přepínač : </translation>
    </message>
    <message>
        <source>Set debug messages verbosity</source>
        <translation>Nastaví podrobnost výpisu ladících zpráv</translation>
    </message>
    <message>
        <source>(n = -1 .. 5)</source>
        <translation>(n = -1 .. 5)</translation>
    </message>
    <message>
        <source>label item</source>
        <translation>položka &apos;label&apos;</translation>
    </message>
    <message>
        <source>Content Stream</source>
        <translation>Content Stream</translation>
    </message>
    <message>
        <source>Parameter</source>
        <translation>Parametr</translation>
    </message>
    <message>
        <source>Operator</source>
        <translation>Operátor</translation>
    </message>
    <message>
        <source>page</source>
        <comment>1</comment>
        <translation>strana</translation>
    </message>
    <message>
        <source>pages</source>
        <comment>2-4</comment>
        <translation>strany</translation>
    </message>
    <message>
        <source>pages</source>
        <comment>5+</comment>
        <translation>stran</translation>
    </message>
    <message>
        <source>parameter</source>
        <comment>1</comment>
        <translation>parametr</translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>2-4</comment>
        <translation>parametry</translation>
    </message>
    <message>
        <source>parameters</source>
        <comment>5+</comment>
        <translation>parametrů</translation>
    </message>
    <message>
        <source>child</source>
        <comment>1</comment>
        <translation>potomek</translation>
    </message>
    <message>
        <source>childs</source>
        <comment>2-4</comment>
        <translation>potomci</translation>
    </message>
    <message>
        <source>childs</source>
        <comment>5+</comment>
        <translation>potomků</translation>
    </message>
    <message>
        <source>Pick a file ...</source>
        <translation>Vyberte soubor ...</translation>
    </message>
    <message>
        <source>New revision of document created</source>
        <translation>Vytvořena nová revize dokumentu</translation>
    </message>
    <message>
        <source>Error occured while loading file</source>
        <translation>Nastala chyba při nahrávání souboru</translation>
    </message>
    <message>
        <source>Image was not saved!</source>
        <translation>Obrázek nebyl uložen!</translation>
    </message>
    <message>
        <source>Changed revision to:</source>
        <translation>Změněna revize:</translation>
    </message>
    <message>
        <source>Operators</source>
        <translation>Operátory</translation>
    </message>
    <message>
        <source>Warning: This document is linearized PDF!</source>
        <translation>Upozornění: Tento dokument je linearizované PDF!</translation>
    </message>
    <message>
        <source>Show all operators</source>
        <translation>Zobrazit všechny operátory</translation>
    </message>
    <message>
        <source>Show only text operators</source>
        <translation>Zobrazit jen textové operátory</translation>
    </message>
    <message>
        <source>Showing all</source>
        <comment>mode</comment>
        <translation>Zobrazuji vše</translation>
    </message>
    <message>
        <source>Showing text. op.</source>
        <comment>mode</comment>
        <translation>Zobrazuji text. op.</translation>
    </message>
    <message>
        <source>Null pointer access in </source>
        <translation>Přístup na null ukazatel v </translation>
    </message>
    <message>
        <source>Show only font operators</source>
        <translation>Zobrazit jen font operátory</translation>
    </message>
    <message>
        <source>Showing font. op.</source>
        <comment>mode</comment>
        <translation>Zobrazuji font. op.</translation>
    </message>
    <message>
        <source>Warning: This document is encrypted!</source>
        <translation>Upozornění: Tento dokument je zašifrovaný!</translation>
    </message>
    <message>
        <source>Encryption filter:</source>
        <translation>Šifrovací filtr:</translation>
    </message>
    <message>
        <source>No page selected!</source>
        <translation>Není zvolena žádná stránka!</translation>
    </message>
    <message>
        <source>Must define color</source>
        <translation>Je nutno definovat barvu</translation>
    </message>
    <message>
        <source>r,g,b must be number</source>
        <translation>r,g,b musí být číslo</translation>
    </message>
    <message>
        <source>r,g,b must be from 0 to 255</source>
        <translation>r,g,b musí být z 0 až 255</translation>
    </message>
    <message>
        <source>Left upper corner</source>
        <translation>Levý horní roh</translation>
    </message>
    <message>
        <source>x position</source>
        <translation>x souřadnice</translation>
    </message>
    <message>
        <source>y position</source>
        <translation>y souřadnice</translation>
    </message>
    <message>
        <source>Right bottom corner</source>
        <translation>Pravý dolní roh</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Storno</translation>
    </message>
    <message>
        <source>Set color</source>
        <translation>Nastavit barvu</translation>
    </message>
    <message>
        <source>Set font properties</source>
        <translation>Nastavit vlastnosti fontu</translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <translation>Nastavit styl čáry</translation>
    </message>
    <message>
        <source>Set line width</source>
        <translation>Nastavit šířku čáry</translation>
    </message>
    <message>
        <source>Add system font</source>
        <translation>Přidat systémový font</translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <translation>Extrahovat text ze stránky</translation>
    </message>
    <message>
        <source>Page rotated.</source>
        <translation>Stránka otočena.</translation>
    </message>
    <message>
        <source>MediaBox changed.</source>
        <translation>MediaBox změněn.</translation>
    </message>
    <message>
        <source>No page or operator selected!</source>
        <translation>Není zvolena stránka nebo operátor!</translation>
    </message>
    <message>
        <source>Selected operator</source>
        <translation>Zvolený operátor</translation>
    </message>
    <message>
        <source>is not</source>
        <translation>není</translation>
    </message>
    <message>
        <source>suitable for colour setting.</source>
        <translation>vhodný pro nastavení barvy.</translation>
    </message>
    <message>
        <source>suitable for line width change.</source>
        <translation>vhodný pro nastavení šířky čáry.</translation>
    </message>
    <message>
        <source>Line width changed.</source>
        <translation>Šířka čáry změněna.</translation>
    </message>
    <message>
        <source>suitable for dash style change.</source>
        <translation>vhodný pro nastavení stylu čáry.</translation>
    </message>
    <message>
        <source>Dash pattern changed.</source>
        <translation>Styl čáry změněn.</translation>
    </message>
    <message>
        <source>text operator</source>
        <translation>textový operátor</translation>
    </message>
    <message>
        <source>Font changed.</source>
        <translation>Písmo změněno.</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>Přidat písmo</translation>
    </message>
    <message>
        <source>Add system fonts</source>
        <translation>Přidat systémové písmo</translation>
    </message>
    <message>
        <source>Avaliable system fonts</source>
        <translation>Dostupná systémová písma</translation>
    </message>
    <message>
        <source>Select system Type1 font</source>
        <translation>Vyberte systémové Type1 písmo</translation>
    </message>
    <message>
        <source>System font added.</source>
        <translation>Systémové písmo přidáno.</translation>
    </message>
    <message>
        <source>Text on page</source>
        <translation>Text na stránce</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
    <message>
        <source>Text extracted from page</source>
        <translation>Text získaný ze stránky</translation>
    </message>
    <message>
        <source>Page text displayed</source>
        <translation>Text stránky zobrazen</translation>
    </message>
    <message>
        <source>Operator must be</source>
        <translation>Operátor musí být</translation>
    </message>
    <message>
        <source>No preceding font operator found...</source>
        <translation>Nenalezen žádný předcházející operátor písma...</translation>
    </message>
    <message>
        <source>Invalid operand type</source>
        <translation>Neplatný typ operandu</translation>
    </message>
    <message>
        <source>This option is not supported.</source>
        <translation>Tato volba není podporována.</translation>
    </message>
    <message>
        <source>Show only graphical operators</source>
        <translation>Zobrazovat pouze grafické operátory</translation>
    </message>
    <message>
        <source>Set relative position of a single operator</source>
        <translation>Nastavit relativní pozici jednoho operátoru</translation>
    </message>
    <message>
        <source>Set relative position</source>
        <translation>Nastavit relativní pozici</translation>
    </message>
    <message>
        <source>Set page tranformation matrix</source>
        <translation>Nastavit transformační matici stránky</translation>
    </message>
    <message>
        <source>Change page rectangle</source>
        <translation>Změnit rámeček stránky</translation>
    </message>
    <message>
        <source>Change</source>
        <translation>Změnit</translation>
    </message>
    <message>
        <source>Page metrics</source>
        <translation>Metrika stránky</translation>
    </message>
    <message>
        <source>Change effect</source>
        <translation>Efekt změny</translation>
    </message>
    <message>
        <source>Global change</source>
        <translation>Globální změna</translation>
    </message>
    <message>
        <source>Change line dash pattern</source>
        <translation>Změnit styl čáry</translation>
    </message>
    <message>
        <source>Line dashing patterns</source>
        <translation>Styl čáry</translation>
    </message>
    <message>
        <source>Solid line</source>
        <translation>Plná čára</translation>
    </message>
    <message>
        <source>Slightly dashed</source>
        <translation>Přerušovaná čára</translation>
    </message>
    <message>
        <source>Dot and dashed</source>
        <translation>Čerchovaná čára</translation>
    </message>
    <message>
        <source>Not valid</source>
        <translation>Neplatný</translation>
    </message>
    <message>
        <source>Only text operators allowed!</source>
        <translation>Povoleny pouze textové operátory!</translation>
    </message>
    <message>
        <source>Add page transformation matrix</source>
        <translation>Přidat transformační matici stránky</translation>
    </message>
    <message>
        <source>Change page transformation matrix</source>
        <translation>Změnit transformační matici stránky</translation>
    </message>
    <message>
        <source>Page transformation matrix description</source>
        <translation>Popis transformační matice stránky</translation>
    </message>
    <message>
        <source>Page transformation description</source>
        <translation>Popis transformací stránky</translation>
    </message>
    <message>
        <source>Select which transformations to use</source>
        <translation>Vyberte, které transformace použít</translation>
    </message>
    <message>
        <source>Translate (shift) page</source>
        <translation>Posunutí stránky</translation>
    </message>
    <message>
        <source>Scale page</source>
        <translation>Změna měřítka stránky</translation>
    </message>
    <message>
        <source>Skew page</source>
        <translation>Zkosení stránky</translation>
    </message>
    <message>
        <source>Page translation</source>
        <translation>Posun stránky</translation>
    </message>
    <message>
        <source>Page scaling</source>
        <translation>Změna měřítka stránky</translation>
    </message>
    <message>
        <source>Page skewing</source>
        <translation>Zkosení stránky</translation>
    </message>
    <message>
        <source>Invalid number supplied.</source>
        <translation>Zadáno neplatné číslo</translation>
    </message>
    <message>
        <source>Page transformation matrix changed to </source>
        <translation>Transformační matice stránky změněna na </translation>
    </message>
    <message>
        <source>Could not find text positioning.</source>
        <translation>Nemohu najít pozicování textu</translation>
    </message>
    <message>
        <source>Change relative text operator position</source>
        <translation>Změnit relativní pozici textového operátoru</translation>
    </message>
    <message>
        <source>Change relative text position</source>
        <translation>Změnit relativní pozici textu</translation>
    </message>
    <message>
        <source>Operator position changed.</source>
        <translation>Pozice operátoru změněna.</translation>
    </message>
    <message>
        <source>Showing graphic. op.</source>
        <comment>mode</comment>
        <translation>Zobrazuji graf. op.</translation>
    </message>
    <message>
        <source>element</source>
        <comment>1</comment>
        <translation>prvek</translation>
    </message>
    <message>
        <source>elements</source>
        <comment>2-4</comment>
        <translation>prvky</translation>
    </message>
    <message>
        <source>elements</source>
        <comment>5+</comment>
        <translation>prvků</translation>
    </message>
    <message>
        <source>item</source>
        <comment>1</comment>
        <translation>položka</translation>
    </message>
    <message>
        <source>items</source>
        <comment>2-4</comment>
        <translation>položky</translation>
    </message>
    <message>
        <source>items</source>
        <comment>5+</comment>
        <translation>položek</translation>
    </message>
    <message>
        <source>Add item to dictionary</source>
        <translation>Přidat položku do slovníku</translation>
    </message>
    <message>
        <source>Add element to array</source>
        <translation>Přidat prvek do pole</translation>
    </message>
    <message>
        <source>Save page as image</source>
        <translation>Uložit stránku jako obrázek</translation>
    </message>
    <message>
        <source>Save selected area as image</source>
        <translation>Uložit zvolený výřez jako obrázek</translation>
    </message>
    <message>
        <source>Annotation</source>
        <translation>Anotace</translation>
    </message>
    <message>
        <source>Draw line</source>
        <translation>Nakreslit čáru</translation>
    </message>
    <message>
        <source>Line was drawn.</source>
        <translation>Čára nakreslena.</translation>
    </message>
    <message>
        <source>Encrypted content will show up as garbage and many operations will be impossible</source>
        <translation>Zašifrovaný obsah bude vypadat jako smetí a mnoho operací nebude možných</translation>
    </message>
    <message>
        <source>Rect was drawn.</source>
        <translation>Obdélník byl nakreslen.</translation>
    </message>
    <message>
        <source>Draw rect</source>
        <translation>Nakreslit obdélník</translation>
    </message>
    <message>
        <source>Add text</source>
        <translation>Přidat text</translation>
    </message>
    <message>
        <source>position</source>
        <translation>pozice</translation>
    </message>
    <message>
        <source>Set values</source>
        <translation>Nastavit hodnoty</translation>
    </message>
    <message>
        <source>Relative operator position (this is not absolute position)</source>
        <translation>Relativní pozice operátoru (toto není absolutní pozice)</translation>
    </message>
    <message>
        <source>Relative operator position</source>
        <translation>Relativní pozice operátoru</translation>
    </message>
    <message>
        <source>Remove page</source>
        <translation>Odstranit stránku</translation>
    </message>
    <message>
        <source>View page</source>
        <translation>Zobrazit stránku</translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytů</translation>
    </message>
    <message>
        <source>Usage:</source>
        <translation>Použití:</translation>
    </message>
    <message>
        <source>input file</source>
        <translation>vstupní soubor</translation>
    </message>
    <message>
        <source>output file</source>
        <translation>výstupní soubor</translation>
    </message>
    <message>
        <source>Input file must exist</source>
        <translation>Vstupní soubor musí existovat</translation>
    </message>
    <message>
        <source>Output file must not exist</source>
        <translation>Výstupní soubor nesmí existovat</translation>
    </message>
    <message>
        <source>is expecting two parameters</source>
        <translation>očekává dva parametry</translation>
    </message>
    <message>
        <source>Input file &apos;%1&apos; does not exist</source>
        <translation>Vstupní soubor &apos;%1&apos; neexistuje</translation>
    </message>
    <message>
        <source>Output file &apos;%1&apos; already exist</source>
        <translation>Výstupní soubor &apos;%1&apos; již existuje</translation>
    </message>
    <message>
        <source>Delinearized</source>
        <translation>Delinearizováno</translation>
    </message>
    <message>
        <source>Available functions:</source>
        <translation>Dostupné funkce:</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>Popis</translation>
    </message>
    <message>
        <source>Parameters</source>
        <translation>Parametry</translation>
    </message>
    <message>
        <source>Filename</source>
        <translation>Jméno souboru</translation>
    </message>
    <message>
        <source>No function found matching &apos;%1&apos;</source>
        <translation>Nenalezena funkce odpovídající &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Too many function found matching &apos;%1&apos;</source>
        <translation>Nalezeno příliš mnoho funkcí odpovídajících &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Matching functions</source>
        <translation>Odpovídající funkce</translation>
    </message>
    <message>
        <source>Running</source>
        <translation>Spouštím</translation>
    </message>
    <message>
        <source>First parameter is name of function to invoke (case insensitive) or its unambiguous part.</source>
        <translation>První parametr je název funkce, která se zavolá (nezáleží na velikosti písmen) nebo jeho jednoznačná část.</translation>
    </message>
    <message>
        <source>Rest of parameters are passed to invoked function.</source>
        <translation>Zbytek parametrů je předán volané funkci.</translation>
    </message>
    <message>
        <source>Run in commandline mode</source>
        <translation>Spustit v režimu příkazového řádku</translation>
    </message>
    <message>
        <source>file</source>
        <translation>soubor</translation>
    </message>
    <message>
        <source>Run script from script path or current directory if not found</source>
        <translation>Spustí skript z cesty ke skriptům nebo z aktuálního adresáře, pokud není nalezen</translation>
    </message>
    <message>
        <source>Run script from current directory</source>
        <translation>Spustí skript z aktuálního adresáře</translation>
    </message>
    <message>
        <source>code</source>
        <translation>kód</translation>
    </message>
    <message>
        <source>Evaluate script code</source>
        <translation>Spustit skriptový kód</translation>
    </message>
    <message>
        <source>function name</source>
        <translation>jméno funkce</translation>
    </message>
    <message>
        <source>function parameter(s)</source>
        <translation>parametr(y) funkce</translation>
    </message>
    <message>
        <source>option(s)</source>
        <translation>přepínač(e)</translation>
    </message>
    <message>
        <source>files(s)</source>
        <translation>soubor(y)</translation>
    </message>
    <message>
        <source>Please see the pdf specification for details.</source>
        <translation>Podívejte se do pdf specifikace pro detaily.</translation>
    </message>
    <message>
        <source>Text on a page.</source>
        <translation>Text na stránce.</translation>
    </message>
    <message>
        <source>Shortcut for</source>
        <translation>Zkratka pro</translation>
    </message>
    <message>
        <source>complex item is not shown</source>
        <comment>1</comment>
        <translation>komplexní položka není zobrazena</translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>2-4</comment>
        <translation>komplexní položky nejsou zobrazeny</translation>
    </message>
    <message>
        <source>complex items are not shown</source>
        <comment>5+</comment>
        <translation>komplexních položek není zobrazeno</translation>
    </message>
    <message>
        <source>out of range</source>
        <translation>mimo rozsah</translation>
    </message>
    <message>
        <source>Search text</source>
        <translation>Hledat text</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Hledat</translation>
    </message>
    <message>
        <source>Text :</source>
        <translation>Text :</translation>
    </message>
    <message>
        <source>Find what</source>
        <translation>Co hledat</translation>
    </message>
    <message>
        <source>On currently viewed page only</source>
        <translation>Pouze na zobrazené stránce</translation>
    </message>
    <message>
        <source>Nothing was found.</source>
        <translation>Nebylo nic nalezeno.</translation>
    </message>
    <message>
        <source>Overwrite?</source>
        <translation>Přepsat?</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Otevřít</translation>
    </message>
    <message>
        <source>&amp;Up</source>
        <translation>Nahor&amp;u</translation>
    </message>
    <message>
        <source>&amp;Down</source>
        <translation>&amp;Dolů</translation>
    </message>
    <message>
        <source>File called &quot;%1&quot; already exists. Do you want to overwrite it?</source>
        <translation>Soubor s názvem &quot;%1&quot; již existuje. Chcete ho přepsat?</translation>
    </message>
    <message>
        <source>Delinearization failed!</source>
        <translation>Delinearizace selhala!</translation>
    </message>
    <message>
        <source>Colour changed</source>
        <translation>Barva změněna</translation>
    </message>
    <message>
        <source>for</source>
        <translation>pro</translation>
    </message>
    <message>
        <source>operators</source>
        <translation>operátor(ů)</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation>Anotace</translation>
    </message>
    <message>
        <source>Input and output files must be different</source>
        <translation>Vstupní a výstupní soubor musí být jiný</translation>
    </message>
    <message>
        <source>changeable</source>
        <translation>měnitelný</translation>
    </message>
    <message>
        <source>Delinearize</source>
        <translation>Delinearizovat</translation>
    </message>
    <message>
        <source>%1 added to page</source>
        <translation>%1 přidán na stránku</translation>
    </message>
    <message>
        <source>Operator %1 is not changeable</source>
        <translation>Operátor %1 není měnitelný</translation>
    </message>
    <message>
        <source>Operator cm must have array with 6 numbers as parameter!</source>
        <translation>Operátor cm musí mít pole 6 čísel jako parametr!</translation>
    </message>
    <message>
        <source>X and Y position must be a number</source>
        <translation>X a Y pozice musí být číslo</translation>
    </message>
    <message>
        <source>Dictionary has no type!</source>
        <translation>Slovník nemá žádný typ!</translation>
    </message>
    <message>
        <source>Maybe bad stream!</source>
        <translation>Pravděpodobně špatný stream!</translation>
    </message>
    <message>
        <source>%1 is requirement for %2, but not found for it !</source>
        <translation>%1 je požadováno pro %2, ale nebylo nalezeno !</translation>
    </message>
    <message>
        <source>For child %1 of %2 is requirement %3 subchild, but has %4</source>
        <translation>Pro potomka %1 je %2 požadován potomek %3, ale je tam %4</translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have 1 parameter, but has %2 !</source>
        <translation>Operátor &apos;%1&apos; má mít 1 parametr, ale má %2 !</translation>
    </message>
    <message>
        <source>Operator &apos;%1&apos; should have %2 parameters, but has %3 !</source>
        <translation>Operátor &apos;%1&apos; má mít %2 parametrů, ale má %3 !</translation>
    </message>
    <message>
        <source>Page parameter must be defined!</source>
        <translation>Parametr stránky musí být definován!</translation>
    </message>
    <message>
        <source>Matrix is in bad state !</source>
        <translation>Matice je ve špatném stavu !</translation>
    </message>
    <message>
        <source>Document is read-only</source>
        <translation>Dokument je pouze pro čtení</translation>
    </message>
    <message>
        <source>Move one level up</source>
        <translation>Posunout o úroveň nahoru</translation>
    </message>
    <message>
        <source>Move one level down</source>
        <translation>Posunout o úroveň dolů</translation>
    </message>
    <message>
        <source>Invalid operation</source>
        <translation>Neplatná operace</translation>
    </message>
    <message>
        <source>xml files (*.xml)</source>
        <translation>xml soubory (*.xml)</translation>
    </message>
    <message>
        <source>Save as text file</source>
        <translation>Uložit jako textový soubor</translation>
    </message>
    <message>
        <source>Text saved to %1</source>
        <translation>Text uložen do %1</translation>
    </message>
    <message>
        <source>Font face</source>
        <translation>Písmo</translation>
    </message>
    <message>
        <source>Font size (in points)</source>
        <translation>Velikost písma (v bodech)</translation>
    </message>
    <message>
        <source>Line width (in points)</source>
        <translation>Šířka čáry (v bodech)</translation>
    </message>
    <message>
        <source>Use &apos;%1 --help&apos; to see list of commandline options and their parameters</source>
        <translation>Použijte &apos;%1 --help&apos; k zobrazení seznamu přepínačů na příkazové řádce a jejich parametrů</translation>
    </message>
    <message>
        <source>Saved as</source>
        <translation>Uloženo jako</translation>
    </message>
    <message>
        <source>Unable to open file: %1</source>
        <translation>Nelze otevřít soubor: %1</translation>
    </message>
    <message>
        <source>Not implemented: %1</source>
        <translation>Nepodporováno: %1</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Neznámá chyba</translation>
    </message>
    <message>
        <source>Apply from page</source>
        <translation>Aplikovat od strany</translation>
    </message>
    <message>
        <source>How many pages</source>
        <translation>Kolik stran</translation>
    </message>
</context>
<context>
    <name>annotation_type</name>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Link</source>
        <translation>Odkaz</translation>
    </message>
    <message>
        <source>FreeText</source>
        <translation>FreeText</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Čára</translation>
    </message>
    <message>
        <source>Square</source>
        <translation>Čtverec</translation>
    </message>
    <message>
        <source>Circle</source>
        <translation>Kružnice</translation>
    </message>
    <message>
        <source>Polygon</source>
        <translation>Mnohoúhelník</translation>
    </message>
    <message>
        <source>PolyLine</source>
        <translation>Lomená čára</translation>
    </message>
    <message>
        <source>Highlight</source>
        <translation>Zvýraznění</translation>
    </message>
    <message>
        <source>Underline</source>
        <translation>Podtržení</translation>
    </message>
    <message>
        <source>Squiggly</source>
        <translation>Zvlněné podtržení</translation>
    </message>
    <message>
        <source>StrikeOut</source>
        <translation>Přeškrtnutí</translation>
    </message>
    <message>
        <source>Stamp</source>
        <translation>Razítko</translation>
    </message>
    <message>
        <source>Caret</source>
        <translation>Kurzor</translation>
    </message>
    <message>
        <source>Ink</source>
        <translation>Kresba</translation>
    </message>
    <message>
        <source>Popup</source>
        <translation>Popup</translation>
    </message>
    <message>
        <source>Fileattachement</source>
        <translation>Příloha (soubor)</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Zvuk</translation>
    </message>
    <message>
        <source>Movie</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Widget</source>
        <translation>Widget</translation>
    </message>
    <message>
        <source>Screen</source>
        <translation>Obrazovka</translation>
    </message>
    <message>
        <source>Printermark</source>
        <translation>Tisková značka</translation>
    </message>
    <message>
        <source>Trapnet</source>
        <translation>Trapnet</translation>
    </message>
    <message>
        <source>Watermark</source>
        <translation>Vodoznak</translation>
    </message>
    <message>
        <source>3D</source>
        <translation>3D</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznámá</translation>
    </message>
</context>
<context>
    <name>gui::AboutWindow</name>
    <message>
        <source>About program</source>
        <translation>O programu</translation>
    </message>
    <message>
        <source>Compiled</source>
        <translation>Zkompilováno</translation>
    </message>
    <message>
        <source>This program is distributed under terms of GNU GPL</source>
        <translation>Tento program je distribuován pod GNU GPL licencí</translation>
    </message>
    <message>
        <source>Homepage</source>
        <translation>Stránka</translation>
    </message>
    <message>
        <source>Free program for PDF document manipulation</source>
        <translation>Svobodný program pro manipulaci s PDF dokumenty</translation>
    </message>
    <message>
        <source>Project page</source>
        <translation>Stránka projektu</translation>
    </message>
    <message>
        <source>Using Qt %1</source>
        <translation>Použito Qt %1</translation>
    </message>
    <message>
        <source>, QSA %1</source>
        <translation>, QSA %1</translation>
    </message>
</context>
<context>
    <name>gui::AddItemDialog</name>
    <message>
        <source>Add object</source>
        <translation>Přidat objekt</translation>
    </message>
    <message>
        <source>Type and value of new object</source>
        <translation>Typ a hodnota nového objektu</translation>
    </message>
    <message>
        <source>New empty Dictionary</source>
        <translation>Nový prázndný slovník</translation>
    </message>
    <message>
        <source>New empty Array</source>
        <translation>Nové prázdné pole</translation>
    </message>
    <message>
        <source>Property name</source>
        <translation>Jméno položky</translation>
    </message>
    <message>
        <source>No object type selected</source>
        <translation>Není zvolen typ objektu</translation>
    </message>
    <message>
        <source>Entered property is not valid</source>
        <translation>Zadaná položka není platná</translation>
    </message>
    <message>
        <source>Name of new property must be specified</source>
        <translation>Musí být zadané jméno položky</translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; added to dictionary</source>
        <translation>Položka &apos;%1&apos; přidána do slovníku</translation>
    </message>
    <message>
        <source>Property added to end of array</source>
        <translation>Položka přidána na konec pole</translation>
    </message>
    <message>
        <source>Property &apos;%1&apos; already exist as %2</source>
        <translation>Položka &apos;%1&apos; již existuje jako %2</translation>
    </message>
    <message>
        <source>Reference target does not exist!</source>
        <translation>Cíl reference neexistuje!</translation>
    </message>
    <message>
        <source>Add to position</source>
        <translation>Vložit na pozici</translation>
    </message>
    <message>
        <source>Append to end</source>
        <translation>Přidat na konec</translation>
    </message>
    <message>
        <source>Property added to position %1 in array</source>
        <translation>Položka přidána na pozici &apos;%1&apos; v poli</translation>
    </message>
    <message>
        <source>Array index %1 out of range</source>
        <translation>Index pole %1 je mimo rozsah</translation>
    </message>
</context>
<context>
    <name>gui::AnnotDialog</name>
    <message>
        <source>Text Annotation</source>
        <translation>Textová Anotace</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>&amp;Otevřená</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Obsah</translation>
    </message>
    <message>
        <source>Icon &amp;Name</source>
        <translation>Jmé&amp;no ikony</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Komentář</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Nápověda (Help)</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Vložit (Insert)</translation>
    </message>
    <message>
        <source>Key</source>
        <translation>Klíč (Key)</translation>
    </message>
    <message>
        <source>NewParagraph</source>
        <translation>Nový Odstavec (NewParagraph)</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Poznámka (Note)</translation>
    </message>
    <message>
        <source>Paragraph</source>
        <translation>Odstavec (Paragraph)</translation>
    </message>
    <message>
        <source>&amp;State</source>
        <translation>&amp;Stav</translation>
    </message>
    <message>
        <source>Marked</source>
        <translation>Označená</translation>
    </message>
    <message>
        <source>Unmarked</source>
        <translation>Neoznačená</translation>
    </message>
    <message>
        <source>State &amp;Model</source>
        <translation>&amp;Model stavů</translation>
    </message>
    <message>
        <source>Review</source>
        <translation>Přezkoumání</translation>
    </message>
    <message>
        <source>&amp;Text Annotation</source>
        <translation>&amp;Textová anotace</translation>
    </message>
    <message>
        <source>&amp;Destination</source>
        <translation>Cíl</translation>
    </message>
    <message>
        <source>&amp;Highlight mode</source>
        <translation>
Režim zvýraznění</translation>
    </message>
    <message>
        <source>N - None</source>
        <translation>N - Žádný</translation>
    </message>
    <message>
        <source>I - Invert</source>
        <translation>I - Inverze</translation>
    </message>
    <message>
        <source>O - Outline</source>
        <translation>O - Obrys</translation>
    </message>
    <message>
        <source>P - Push</source>
        <translation>P - Vytlačený okraj</translation>
    </message>
    <message>
        <source>&amp;Link Annotation</source>
        <translation>&amp;Link anotace (odkaz)</translation>
    </message>
    <message>
        <source>Add new annotation</source>
        <translation>Přidat novou anotaci</translation>
    </message>
</context>
<context>
    <name>gui::Base</name>
    <message>
        <source>Warning</source>
        <translation>Upozornění</translation>
    </message>
    <message>
        <source>No init script found - check your configuration</source>
        <translation>Nenalezen žádný init skript - zkontrolujte svoji konfiguraci</translation>
    </message>
    <message>
        <source>Looked for</source>
        <comment>scripts</comment>
        <translation>Zkoušel jsem</translation>
    </message>
    <message>
        <source>Error running</source>
        <translation>Chyba při spouštění</translation>
    </message>
    <message>
        <source>Script not found</source>
        <translation>Skript nenalezen</translation>
    </message>
</context>
<context>
    <name>gui::BaseCore</name>
    <message>
        <source>Error in callback handler: </source>
        <translation>Chyba v obsluze volání: </translation>
    </message>
    <message>
        <source>Exception in callback handler: </source>
        <translation>Výjimka v obsluze volání: </translation>
    </message>
    <message>
        <source>Unknown exception in script occured</source>
        <translation>Ve skriptu došlo k neznámé výjimce</translation>
    </message>
    <message>
        <source>Null pointer access in </source>
        <translation>Přístup na null ukazatel v </translation>
    </message>
    <message>
        <source>Invalid object given for parameter %1 in </source>
        <translation>Neplatný objekt předán jako parametr %1 v </translation>
    </message>
    <message>
        <source>Expected</source>
        <comment>object type</comment>
        <translation>Očekáváno</translation>
    </message>
    <message>
        <source>Got</source>
        <comment>object type</comment>
        <translation>Předáno</translation>
    </message>
    <message>
        <source>In script</source>
        <translation>Ve skriptu</translation>
    </message>
    <message>
        <source>line</source>
        <translation>řádka</translation>
    </message>
    <message>
        <source>Exception in </source>
        <translation>Výjimka v </translation>
    </message>
</context>
<context>
    <name>gui::BaseGUI</name>
    <message>
        <source>No document opened</source>
        <translation>Není otevřen dokument</translation>
    </message>
</context>
<context>
    <name>gui::ColorTool</name>
    <message>
        <source>Choose color</source>
        <translation>Vyberte barvu</translation>
    </message>
    <message>
        <source>Foreground</source>
        <translation>Popředí</translation>
    </message>
    <message>
        <source>Background</source>
        <translation>Pozadí</translation>
    </message>
</context>
<context>
    <name>gui::HelpWindow</name>
    <message>
        <source>help</source>
        <translation>nápověda</translation>
    </message>
</context>
<context>
    <name>gui::MergeDialog</name>
    <message>
        <source>Insert pages from another document</source>
        <translation>Vložit stránky z jiného dokumentu</translation>
    </message>
    <message>
        <source>&amp;Filename</source>
        <translation>Jméno souboru</translation>
    </message>
    <message>
        <source>Open file with pages to be inserted</source>
        <translation>Otevřít soubor se stránkami k vložení</translation>
    </message>
</context>
<context>
    <name>gui::MultiTreeWindow</name>
    <message>
        <source>Tree</source>
        <translation>Strom</translation>
    </message>
    <message>
        <source>Close current tab</source>
        <translation>Zavřít aktuální záložku</translation>
    </message>
    <message>
        <source>Document tree</source>
        <translation>Strom dokumentu</translation>
    </message>
    <message>
        <source>Switch to ...</source>
        <translation>Přepnout na ...</translation>
    </message>
</context>
<context>
    <name>gui::OptionWindow</name>
    <message>
        <source>options</source>
        <translation>nastavení</translation>
    </message>
    <message>
        <source>Icon Path</source>
        <translation>Cesta k ikonám</translation>
    </message>
    <message>
        <source>Editor</source>
        <translation>Editor</translation>
    </message>
    <message>
        <source>Advanced mode</source>
        <translation>Režim pro pokročilé</translation>
    </message>
    <message>
        <source>Object tree</source>
        <translation>Strom objektů</translation>
    </message>
    <message>
        <source>Document dictionary</source>
        <translation>Slovník dokumentu</translation>
    </message>
    <message>
        <source>Object dictionaries</source>
        <translation>Slovníky objektů</translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation>Outliny</translation>
    </message>
    <message>
        <source>Graphic objects</source>
        <translation>Grafické objekty</translation>
    </message>
    <message>
        <source>Annotations</source>
        <translation>Anotace</translation>
    </message>
    <message>
        <source>Pages</source>
        <translation>Stránky</translation>
    </message>
    <message>
        <source>Simple Objects</source>
        <translation>Jednoduché objekty</translation>
    </message>
    <message>
        <source>Show return value of executed scripts in console</source>
        <translation>Zobrazovat návratovou hodnotu skriptů v příkazovém řádku</translation>
    </message>
    <message>
        <source>Toolbars</source>
        <translation>Toolbary</translation>
    </message>
    <message>
        <source>History file</source>
        <translation>Soubor historie</translation>
    </message>
    <message>
        <source>Max. lines in history</source>
        <translation>Max. řádek v historii</translation>
    </message>
    <message>
        <source>Look and Feel</source>
        <translation>Vzhled</translation>
    </message>
    <message>
        <source>You can specify overall visual style</source>
        <translation>Zde lze nastavit celkový vzhled</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Styl</translation>
    </message>
    <message>
        <source>Remember path of last opened/saved file</source>
        <translation>Pamatovat si cestu k poslednímu otevřenému/uloženému souboru</translation>
    </message>
    <message>
        <source>Turning on advanced mode will allow more powerful (but also more dangerous) changes to edited document.</source>
        <translation>Zapnutí režimu pro pokročilé umožní složitější (ale také potenciálně nebezpečné) změny v dokumentu.</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Advanced mode will affect only newly opened files</source>
        <translation>&lt;b&gt;Poznámka&lt;/b&gt;: změna Režimu pro pokročilé ovlivní až nově otevřené soubory</translation>
    </message>
    <message>
        <source>Paths</source>
        <translation>Cesty</translation>
    </message>
    <message>
        <source>You can use environment variables (for example $HOME) in settings on this page</source>
        <translation>Lze použít proměnné prostředí (např. $HOME) v nastavení na této stránce</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing Icon Path will take effect on next program start</source>
        <translation>&lt;b&gt;Poznámka&lt;/b&gt;: změna cesty k ikonám bude mít efekt až při přístím startu programu</translation>
    </message>
    <message>
        <source>Console log file</source>
        <translation>Log soubor pro příkazový řádek</translation>
    </message>
    <message>
        <source>These objects will be shown in the object tree</source>
        <translation>Tyto objekty budou zobrazeny ve stromu objektů</translation>
    </message>
    <message>
        <source>These toolbars will be shown:</source>
        <translation>Tyto toolbary budou zobrazeny:</translation>
    </message>
    <message>
        <source>Show errors from event handlers</source>
        <translation>Zobrazovat chyby z funkcí obsluhy událostí</translation>
    </message>
    <message>
        <source>Content Streams</source>
        <translation>Content Stream</translation>
    </message>
    <message>
        <source>Show command editor</source>
        <translation>Zobrazit editor příkazů</translation>
    </message>
    <message>
        <source>Show command line</source>
        <translation>Zobrazit příkazovou řádku</translation>
    </message>
    <message>
        <source>Editable command line</source>
        <translation>Editovatelná příkazová řádka</translation>
    </message>
    <message>
        <source>Script Path</source>
        <translation>Cesta ke skriptům</translation>
    </message>
    <message>
        <source>Scripts to run on start</source>
        <translation>Skripty spouštěné při startu</translation>
    </message>
    <message>
        <source>You can set fonts used in application</source>
        <translation>Zde lze nastavit písma použitá v editoru</translation>
    </message>
    <message>
        <source>Application font</source>
        <translation>Písmo aplikace</translation>
    </message>
    <message>
        <source>Console font</source>
        <translation>Písmo v příkazovém řádku</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Téma ikon</translation>
    </message>
    <message>
        <source>Use big icons</source>
        <translation>Použít velké ikony</translation>
    </message>
    <message>
        <source>Show hidden properties</source>
        <translation>Zobrazovat skryté položky</translation>
    </message>
    <message>
        <source>Allow editing read-only properties</source>
        <translation>Povolit měnit položky pouze pro čtení</translation>
    </message>
    <message>
        <source>Commandline</source>
        <translation>Příkazová řádka</translation>
    </message>
    <message>
        <source>Commandline options</source>
        <translation>Nastavení příkazové řádky</translation>
    </message>
    <message>
        <source>Options affecting object tree and property editor</source>
        <translation>Nastavení ovlivňující strom objektů a editor položek</translation>
    </message>
    <message>
        <source>Sort dictionary items alphabetically</source>
        <translation>Řadit položky slovníku abecedně</translation>
    </message>
    <message>
        <source>History options</source>
        <translation>Nastavení historie</translation>
    </message>
    <message>
        <source>Statusbar font</source>
        <translation>Písmo stavového řádku</translation>
    </message>
    <message>
        <source>Show return value also for complex types
(possibly long output)</source>
        <translation>Zobrazovat návratovou hodnotu též pro komplexní typy
(možný delší výstup)</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note&lt;/b&gt;: changing icon theme will take effect on next program start</source>
        <translation>&lt;b&gt;Poznámka&lt;/b&gt;: změna tématu ikon bude mít efekt až při přístím startu programu</translation>
    </message>
    <message>
        <source>Character encoding</source>
        <translation>Kódování znaků</translation>
    </message>
    <message>
        <source>Length units</source>
        <translation>Jednotky délky</translation>
    </message>
    <message>
        <source>Page view</source>
        <translation>Náhled stránky</translation>
    </message>
    <message>
        <source>Command Line</source>
        <translation>Příkazová řádka</translation>
    </message>
    <message>
        <source>Initial focus</source>
        <translation>Počáteční výběr</translation>
    </message>
    <message>
        <source>This will specify which part of editor window will receive keyboard focus when new window is opened</source>
        <translation>Toto určuje, která část editoru dostane fokus z klávesnice při otevření nového okna</translation>
    </message>
</context>
<context>
    <name>gui::PageSpace</name>
    <message>
        <source>Save as image ...</source>
        <translation>Uložit jako obrázek...</translation>
    </message>
    <message>
        <source>%1 of %2</source>
        <translation>%1 z %2</translation>
    </message>
</context>
<context>
    <name>gui::PdfEditWindow</name>
    <message>
        <source>Loaded file</source>
        <translation>Nahrán soubor</translation>
    </message>
    <message>
        <source>Current file is not saved. Do you want to save it?</source>
        <translation>Editovaný soubor není uložen. Přejete si ho uložit?</translation>
    </message>
    <message>
        <source>Error while loading document </source>
        <translation>Chyba při nahrávání dokumentu </translation>
    </message>
    <message>
        <source>Unknown error while loading document </source>
        <translation>Neznámá chyba při nahrávání dokumentu </translation>
    </message>
    <message>
        <source>No document to save</source>
        <translation>Není žádný dokument k uložení</translation>
    </message>
    <message>
        <source>viewing revision</source>
        <translation>zobrazuji revizi</translation>
    </message>
    <message>
        <source>Name is empty</source>
        <translation>Jméno je prázdné</translation>
    </message>
    <message>
        <source>Document is in read-only mode</source>
        <translation>Dokument je v režimu pouze pro čtení</translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation>Neznámá chyba při ukládání dokumentu</translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation>Linearizované PDF</translation>
    </message>
    <message>
        <source>Encrypted</source>
        <translation>Zašifrované</translation>
    </message>
    <message>
        <source>Selection</source>
        <translation>Výběr</translation>
    </message>
    <message>
        <source>Selected operators</source>
        <translation>Vybrané operátory</translation>
    </message>
    <message>
        <source>Selected annotations</source>
        <translation>Vybrané anotace</translation>
    </message>
    <message>
        <source>Saving not implemented:
%1</source>
        <translation>Ukládání není implementováno:
%1</translation>
    </message>
    <message>
        <source>Error occured while saving copy:
%1</source>
        <translation>Při ukládání kopie došlo k chybě:
%1</translation>
    </message>
</context>
<context>
    <name>gui::Property</name>
    <message>
        <source>Read only</source>
        <translation>Pouze pro čtení</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Pokročilá</translation>
    </message>
    <message>
        <source>Hidden</source>
        <translation>Skrytá</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Neznámá</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normální</translation>
    </message>
</context>
<context>
    <name>gui::PropertyEditor</name>
    <message>
        <source>No object selected</source>
        <translation>Není zvolen žádný objekt</translation>
    </message>
    <message>
        <source>This type of object does not have any properties</source>
        <translation>Tento typ objektu nemá žádné položky</translation>
    </message>
    <message>
        <source>This operator does not have any directly editable parameters</source>
        <translation>Tento operátor nemá žádné přímo měnitelné parametry</translation>
    </message>
    <message>
        <source>This %1 is empty</source>
        <translation>Tento %1 je prázdný</translation>
    </message>
    <message>
        <source>dictionary</source>
        <comment>property type</comment>
        <translation>slovník</translation>
    </message>
    <message>
        <source>This %1 does not have any directly editable properties</source>
        <translation>Tento %1 nemá žádné přímo měnitelné položky</translation>
    </message>
    <message>
        <source>stream</source>
        <comment>property type</comment>
        <translation>stream</translation>
    </message>
    <message>
        <source>This array is empty</source>
        <translation>Toto pole je prázdné</translation>
    </message>
    <message>
        <source>This array does not have any directly editable elements</source>
        <translation>Toto pole nemá žádné přímo měnitelné prvky</translation>
    </message>
    <message>
        <source>This operator does not have any parameters</source>
        <translation>Tento operátor nemá žádné parametry</translation>
    </message>
</context>
<context>
    <name>gui::QSPage</name>
    <message>
        <source>Invalid operation</source>
        <translation>Neplatná operace</translation>
    </message>
    <message>
        <source>Out of range</source>
        <translation>Mimo rozsah</translation>
    </message>
    <message>
        <source>Unknown exception</source>
        <translation>Neznámá výjimka</translation>
    </message>
</context>
<context>
    <name>gui::QSPdf</name>
    <message>
        <source>Page not found</source>
        <translation>Stránka nenalezena</translation>
    </message>
    <message>
        <source>Document is in read-only mode</source>
        <translation>Dokument je v režimu pouze pro čtení</translation>
    </message>
    <message>
        <source>Unknown error occured while saving document</source>
        <translation>Neznámá chyba při ukládání dokumentu</translation>
    </message>
    <message>
        <source>Unable to save:
%1</source>
        <translation>Nelze uložit:
%1</translation>
    </message>
</context>
<context>
    <name>gui::RefPropertyDialog</name>
    <message>
        <source>Reference target</source>
        <translation>Cíl reference</translation>
    </message>
    <message>
        <source>Choose target for indirect reference</source>
        <translation>Vyberte cíl pro nepřímou referenci</translation>
    </message>
    <message>
        <source>Object number</source>
        <translation>Číslo objektu</translation>
    </message>
    <message>
        <source>Generation number</source>
        <translation>Číslo generace</translation>
    </message>
    <message>
        <source>Reference target is not valid</source>
        <translation>Cíl reference je neplatný</translation>
    </message>
</context>
<context>
    <name>gui::RevisionTool</name>
    <message>
        <source>No revisions</source>
        <translation>Bez revizí</translation>
    </message>
    <message>
        <source>Revision: </source>
        <translation>Revize: </translation>
    </message>
    <message>
        <source>bytes</source>
        <translation>bytů</translation>
    </message>
    <message>
        <source>Linearized PDF</source>
        <translation>Linearizované PDF</translation>
    </message>
</context>
<context>
    <name>gui::SelectPagesDialog</name>
    <message>
        <source>Convert pdf to xml</source>
        <translation>Převést pdf na xml</translation>
    </message>
</context>
<context>
    <name>gui::Settings</name>
    <message>
        <source>Main Toolbar</source>
        <comment>MainToolbar</comment>
        <translation>Hlavní toolbar</translation>
    </message>
    <message>
        <source>&amp;Options</source>
        <comment>opts</comment>
        <translation>Nastavení</translation>
    </message>
    <message>
        <source>Main menu</source>
        <comment>MainMenu</comment>
        <translation>Hlavní menu</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <comment>quit</comment>
        <translation>Konec</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <comment>fload</comment>
        <translation>&amp;Otevřít...</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <comment>fsave</comment>
        <translation>&amp;Uložit</translation>
    </message>
    <message>
        <source>New &amp;Window</source>
        <comment>neww</comment>
        <translation>Nové okno</translation>
    </message>
    <message>
        <source>Page Toolbar</source>
        <comment>PageToolbar</comment>
        <translation>Toolbar stránky</translation>
    </message>
    <message>
        <source>Add object</source>
        <comment>treeAdditem</comment>
        <translation>Přidat objekt</translation>
    </message>
    <message>
        <source>Delete object</source>
        <comment>treeDelitem</comment>
        <translation>Smazat objekt</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>help_index</comment>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <comment>help_about</comment>
        <translation>O Progr&amp;amu</translation>
    </message>
    <message>
        <source>First Page</source>
        <comment>firstpage</comment>
        <translation>První strana</translation>
    </message>
    <message>
        <source>Prev Page</source>
        <comment>prevpage</comment>
        <translation>Předchozí strana</translation>
    </message>
    <message>
        <source>Next Page</source>
        <comment>nextpage</comment>
        <translation>Další strana</translation>
    </message>
    <message>
        <source>Last Page</source>
        <comment>lastpage</comment>
        <translation>Poslední strana</translation>
    </message>
    <message>
        <source>Revision Toolbar</source>
        <comment>RevisionToolbar</comment>
        <translation>Toolbar revizí</translation>
    </message>
    <message>
        <source>Revisions</source>
        <comment>revlabel</comment>
        <translation>Revize</translation>
    </message>
    <message>
        <source>Rotate page 270 degrees</source>
        <comment>rot-90</comment>
        <translation>Otočit stránku o 270 stupňů</translation>
    </message>
    <message>
        <source>Rotate page 90 degrees</source>
        <comment>rot90</comment>
        <translation>Otočit stránku o 90 stupňů</translation>
    </message>
    <message>
        <source>Save &amp;copy...</source>
        <comment>fsavecopy</comment>
        <translation>Uložit kopii...</translation>
    </message>
    <message>
        <source>&amp;Page</source>
        <comment>pagemenu</comment>
        <translation>Strana</translation>
    </message>
    <message>
        <source>Save page as image...</source>
        <comment>savepage</comment>
        <translation>Uložit stranu jako obrázek...</translation>
    </message>
    <message>
        <source>Show all operators in stream</source>
        <comment>streamAll</comment>
        <translation>Zobrazit všechny operátory ve streamu</translation>
    </message>
    <message>
        <source>Show only text operators in stream</source>
        <comment>streamText</comment>
        <translation>Zobrazit pouze textové operátory ve streamu</translation>
    </message>
    <message>
        <source>Show only font operators in stream</source>
        <comment>streamFont</comment>
        <translation>Zobrazit pouze font operátory ve streamu</translation>
    </message>
    <message>
        <source>Operator Toolbar</source>
        <comment>OperatorToolbar</comment>
        <translation>Toolbar operátorů</translation>
    </message>
    <message>
        <source>Edit page metrics</source>
        <comment>editPageMediaBox</comment>
        <translation>Změnit metriky stránky</translation>
    </message>
    <message>
        <source>Close Window</source>
        <comment>closew</comment>
        <translation>Zavřít okno</translation>
    </message>
    <message>
        <source>Show/Hide &amp;commandline</source>
        <comment>hideCmd</comment>
        <translation>Zobrazit/skrýt příkazový řádek</translation>
    </message>
    <message>
        <source>Add system font to page</source>
        <comment>addSystemFont</comment>
        <translation>Přidat systémové písmo na stránku</translation>
    </message>
    <message>
        <source>Extract text from page</source>
        <comment>pagetext</comment>
        <translation>Extrahovat text ze stránky</translation>
    </message>
    <message>
        <source>Zoom &amp;out</source>
        <comment>zoom_out</comment>
        <translation>&amp;Oddálit měřítko</translation>
    </message>
    <message>
        <source>Zoom &amp;in</source>
        <comment>zoom_in</comment>
        <translation>Př&amp;iblížit měřítko</translation>
    </message>
    <message>
        <source>Show only graphical operators in stream</source>
        <comment>streamGfx</comment>
        <translation>Zobrazit jen grafické operátory ve streamu</translation>
    </message>
    <message>
        <source>Selection mode Toolbar</source>
        <comment>SelectionModeToolbar</comment>
        <translation>Toolbar režimů výběru</translation>
    </message>
    <message>
        <source>Select all objects</source>
        <comment>selectAllObjects</comment>
        <translation>Vybírat všechny objekty</translation>
    </message>
    <message>
        <source>Select text</source>
        <comment>selectText</comment>
        <translation>Vybírat text</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <comment>filemenu</comment>
        <translation>Soubor</translation>
    </message>
    <message>
        <source>Save new &amp;revision</source>
        <comment>fsaverev</comment>
        <translation>Uložit novou &amp;revizi</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <comment>showmenu</comment>
        <translation>Zobrazit</translation>
    </message>
    <message>
        <source>Show/Hide &amp;property editor</source>
        <comment>hideProp</comment>
        <translation>Zobrazit/skrýt editor &amp;položek</translation>
    </message>
    <message>
        <source>Show/Hide object &amp;tree</source>
        <comment>hideTree</comment>
        <translation>Zobrazit/skrýt s&amp;trom objektů</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <comment>toolsmenu</comment>
        <translation>Nás&amp;troje</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <comment>editopersmenu</comment>
        <translation>Úpravy</translation>
    </message>
    <message>
        <source>Set color</source>
        <comment>opsetcolor</comment>
        <translation>Nastavit barvu</translation>
    </message>
    <message>
        <source>Set font</source>
        <comment>opsetfont</comment>
        <translation>Nastavit písmo</translation>
    </message>
    <message>
        <source>Set line dash style</source>
        <comment>opsetdash</comment>
        <translation>Nastavit styl čáry</translation>
    </message>
    <message>
        <source>Set line width</source>
        <comment>opsetlinewidth</comment>
        <translation>Nastavit šířku čáry</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <comment>helpmenu</comment>
        <translation>Nápověda</translation>
    </message>
    <message>
        <source>Set page transformation matrix</source>
        <comment>setpagetm</comment>
        <translation>Nastavit transformační matici stránky</translation>
    </message>
    <message>
        <source>Set relative position of operator</source>
        <comment>opsetposop</comment>
        <translation>Nastavit relativní pozici operátoru</translation>
    </message>
    <message>
        <source>Change relative position</source>
        <comment>opsetpos</comment>
        <translation>Nastavit relativní pozici</translation>
    </message>
    <message>
        <source>Show/Hide &amp;status bar</source>
        <comment>hideStatus</comment>
        <translation>Zobrazit/skrýt &amp;stavový řádek</translation>
    </message>
    <message>
        <source>Add text</source>
        <comment>addtext</comment>
        <translation>Přidat text</translation>
    </message>
    <message>
        <source>Draw line</source>
        <comment>drawlinee</comment>
        <translation>Nakreslit čáru</translation>
    </message>
    <message>
        <source>Draw rectangle</source>
        <comment>drawrecte</comment>
        <translation>Nakreslit obdélník</translation>
    </message>
    <message>
        <source>Select annotations</source>
        <comment>selectAnnot</comment>
        <translation>Vybírat anotace</translation>
    </message>
    <message>
        <source>Text Toolbar</source>
        <comment>TextToolBar</comment>
        <translation>Textový Toolbar</translation>
    </message>
    <message>
        <source>&amp;Find text</source>
        <comment>searchText</comment>
        <translation>Hledat text</translation>
    </message>
    <message>
        <source>&amp;Insert Pages from other document</source>
        <comment>mergeDoc</comment>
        <translation>Vlož&amp;it stránky z jiného dokumentu</translation>
    </message>
    <message>
        <source>Draw Toolbar</source>
        <comment>DrawToolbar</comment>
        <translation>Kreslící Toolbar</translation>
    </message>
    <message>
        <source>Move page up</source>
        <comment>pageMoveUp</comment>
        <translation>Posunout stránku nahoru</translation>
    </message>
    <message>
        <source>Move page down</source>
        <comment>pageMoveDown</comment>
        <translation>Posunout stránku dolů</translation>
    </message>
    <message>
        <source>Remove page</source>
        <comment>pageRemove</comment>
        <translation>Odstranit stránku</translation>
    </message>
    <message>
        <source>Highlighting text</source>
        <comment>highlightingtext</comment>
        <translation>Zvýraznit text</translation>
    </message>
    <message>
        <source>Select graphical operators</source>
        <comment>selectGraphical</comment>
        <translation>Vybírat grafické operátory</translation>
    </message>
    <message>
        <source>TreeView Toolbar</source>
        <comment>TreeViewToolbar</comment>
        <translation>Toolbar stromu objektů</translation>
    </message>
    <message>
        <source>Dynamic Toolbar</source>
        <comment>DynamicToolBar</comment>
        <translation>Dynamický Toolbar</translation>
    </message>
    <message>
        <source>Strike through</source>
        <comment>striketrough</comment>
        <translation>Přeškrtnout</translation>
    </message>
    <message>
        <source>Draw arrow</source>
        <comment>drawarrowe</comment>
        <translation>Nakreslit šipku</translation>
    </message>
    <message>
        <source>PageRider Toolbar</source>
        <comment>PageRiderToolbar</comment>
        <translation>Toolbar navigace stránek</translation>
    </message>
    <message>
        <source>Save as text...</source>
        <comment>fsaveastext</comment>
        <translation>Uložit jako text...</translation>
    </message>
    <message>
        <source>Reload Page (show changes)</source>
        <comment>reloadpage</comment>
        <translation>Obnovit stránku (ukázat změny)</translation>
    </message>
</context>
<context>
    <name>gui::TreeItemPdf</name>
    <message>
        <source>Pages</source>
        <translation>Stránky</translation>
    </message>
    <message>
        <source>Outlines</source>
        <translation>Outliny</translation>
    </message>
</context>
<context>
    <name>gui::TreeWindow</name>
    <message>
        <source>Object</source>
        <translation>Objekt</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <source>Data</source>
        <translation>Data</translation>
    </message>
</context>
<context>
    <name>gui::Units</name>
    <message>
        <source>point</source>
        <translation>bod</translation>
    </message>
    <message>
        <source>inch</source>
        <translation>palec</translation>
    </message>
    <message>
        <source>inches</source>
        <translation>palce</translation>
    </message>
    <message>
        <source>hands</source>
        <translation>ruce</translation>
    </message>
    <message>
        <source>hand</source>
        <translation>ruka</translation>
    </message>
    <message>
        <source>foot</source>
        <translation>stopa</translation>
    </message>
    <message>
        <source>feet</source>
        <translation>stopy</translation>
    </message>
    <message>
        <source>link</source>
        <translation>článek</translation>
    </message>
    <message>
        <source>links</source>
        <translation>články</translation>
    </message>
    <message>
        <source>yard</source>
        <translation>yard</translation>
    </message>
    <message>
        <source>yards</source>
        <translation>yardy</translation>
    </message>
    <message>
        <source>rod</source>
        <translation>prut</translation>
    </message>
    <message>
        <source>rods</source>
        <translation>pruty</translation>
    </message>
    <message>
        <source>pole</source>
        <translation>prut</translation>
    </message>
    <message>
        <source>poles</source>
        <translation>pruty</translation>
    </message>
    <message>
        <source>perch</source>
        <translation>prut</translation>
    </message>
    <message>
        <source>perches</source>
        <translation>pruty</translation>
    </message>
    <message>
        <source>fathom</source>
        <translation>sáh</translation>
    </message>
    <message>
        <source>fathoms</source>
        <translation>sáhy</translation>
    </message>
    <message>
        <source>chain</source>
        <translation>řetěz</translation>
    </message>
    <message>
        <source>chains</source>
        <translation>řetězy</translation>
    </message>
    <message>
        <source>furlong</source>
        <translation>brázda</translation>
    </message>
    <message>
        <source>furlongs</source>
        <translation>brázdy</translation>
    </message>
    <message>
        <source>cable</source>
        <translation>kabel</translation>
    </message>
    <message>
        <source>mile</source>
        <translation>míle</translation>
    </message>
    <message>
        <source>miles</source>
        <translation>mil</translation>
    </message>
    <message>
        <source>land</source>
        <translation>legua</translation>
    </message>
    <message>
        <source>lands</source>
        <translation>leguy</translation>
    </message>
    <message>
        <source>league</source>
        <translation>legua</translation>
    </message>
    <message>
        <source>leagues</source>
        <translation>leguy</translation>
    </message>
    <message>
        <source>nautical mile</source>
        <translation>námořní míle</translation>
    </message>
    <message>
        <source>nautical miles</source>
        <translation>námořních mil</translation>
    </message>
    <message>
        <source>pt : point</source>
        <translation>pt : bod</translation>
    </message>
    <message>
        <source>in : inch</source>
        <translation>in : palec</translation>
    </message>
    <message>
        <source>hand : hand</source>
        <translation>hand : ruka</translation>
    </message>
    <message>
        <source>ft : foot</source>
        <translation>ft : stopa</translation>
    </message>
    <message>
        <source>li : link</source>
        <translation>li : článek</translation>
    </message>
    <message>
        <source>yd : yard</source>
        <translation>yd : yard</translation>
    </message>
    <message>
        <source>rd : rod (pole, perch)</source>
        <translation>rd: prut</translation>
    </message>
    <message>
        <source>ch : chain</source>
        <translation>ch : řetěz</translation>
    </message>
    <message>
        <source>mi : mile</source>
        <translation>mi : míle</translation>
    </message>
    <message>
        <source>land : land (league)</source>
        <translation>land : legua</translation>
    </message>
    <message>
        <source>m : meter</source>
        <translation>m : metr</translation>
    </message>
    <message>
        <source>Ym : yottameter</source>
        <translation>Ym : yottametr</translation>
    </message>
    <message>
        <source>Zm : zettameter</source>
        <translation>Zm : zettametr</translation>
    </message>
    <message>
        <source>Em : exameter</source>
        <translation>Em : exametr</translation>
    </message>
    <message>
        <source>Pm : petameter</source>
        <translation>Pm : petametr</translation>
    </message>
    <message>
        <source>Tm : terameter</source>
        <translation>Tm : terametr</translation>
    </message>
    <message>
        <source>Gm : gigameter</source>
        <translation>Gm : gigametr</translation>
    </message>
    <message>
        <source>Mm : megameter</source>
        <translation>Mm : megametr</translation>
    </message>
    <message>
        <source>km : kilometer</source>
        <translation>km : kilometr</translation>
    </message>
    <message>
        <source>hm : hectometer</source>
        <translation>hm : hektometr</translation>
    </message>
    <message>
        <source>dam : decameter</source>
        <translation>dam : dekametr</translation>
    </message>
    <message>
        <source>dm : decimeter</source>
        <translation>dm : decimetr</translation>
    </message>
    <message>
        <source>cm : centimeter</source>
        <translation>cm : centimetr</translation>
    </message>
    <message>
        <source>mm : millimeter</source>
        <translation>mm : milimetr</translation>
    </message>
    <message>
        <source>um : micrometer</source>
        <translation>um : mikrometr</translation>
    </message>
    <message>
        <source>nm : nanometer</source>
        <translation>nm : nanometr</translation>
    </message>
    <message>
        <source>pm : picometer</source>
        <translation>pm : pikometr</translation>
    </message>
    <message>
        <source>fm : femtometer</source>
        <translation>fm : femtometr</translation>
    </message>
    <message>
        <source>am : attometer</source>
        <translation>am : attometr</translation>
    </message>
    <message>
        <source>zm : zeptometer</source>
        <translation>zm : zeptometr</translation>
    </message>
    <message>
        <source>ym : yoctometer</source>
        <translation>ym : yoctometr</translation>
    </message>
    <message>
        <source>A : angstrom</source>
        <translation>A : angstrom</translation>
    </message>
    <message>
        <source>astronomical unit</source>
        <translation>astronomická jednotka</translation>
    </message>
    <message>
        <source>astronomical units</source>
        <translation>astronomické ednotky</translation>
    </message>
    <message>
        <source>AU : astronomical unit</source>
        <translation>AU : astronomická jednotka</translation>
    </message>
    <message>
        <source>light year</source>
        <translation>světelný rok</translation>
    </message>
    <message>
        <source>light years</source>
        <translation>světelné roky</translation>
    </message>
    <message>
        <source>ly : light year</source>
        <translation>ly : světelný rok</translation>
    </message>
    <message>
        <source>parsec</source>
        <translation>parsek</translation>
    </message>
    <message>
        <source>pc : parsec</source>
        <translation>pc : parsek</translation>
    </message>
    <message>
        <source>mil : milli-inch</source>
        <translation>mil : mili-palec</translation>
    </message>
    <message>
        <source>fm. : fathom</source>
        <translation>fm. : sáh</translation>
    </message>
    <message>
        <source>fur. : furlong</source>
        <translation>fur. : brázda</translation>
    </message>
    <message>
        <source>cable : cable</source>
        <translation>cable : kabel</translation>
    </message>
    <message>
        <source>n.m. : nautical mile</source>
        <translation>n.m. : námořní míle</translation>
    </message>
</context>
</TS>
